@@ -8,7 +8,7 @@ package Devel::MAT::SV;
 use strict;
 use warnings;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -293,6 +293,14 @@ sub more_magic
    push @{ $self->{magic} }, [ $type => $flags, $obj_at, $ptr_at ];
 }
 
+sub _more_annotations
+{
+   my $self = shift;
+   my ( $val_at, $name ) = @_;
+
+   push @{ $self->{annotations} }, [ $val_at, $name ];
+}
+
 =head2 outrefs
 
    @refs = $sv->outrefs
@@ -358,6 +366,14 @@ sub _outrefs_matching
       }
    }
 
+   foreach my $ann ( @{ $self->{annotations} || [] } ) {
+      my ( $val_at, $name ) = @$ann;
+      my $val = $self->df->sv_at( $val_at ) or next;
+
+      push @outrefs, $no_desc ? ( strong => $val ) :
+         Reference( $name, strong => $val );
+   }
+
    return @outrefs / 2 if !wantarray;
    return @outrefs;
 }
@@ -422,7 +438,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant immortal => 1;
 use constant basetype => "SV";
 sub new {
@@ -436,13 +452,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -456,7 +472,7 @@ sub is_weak { '' }
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -470,7 +486,7 @@ sub is_weak { '' }
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -479,7 +495,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 1 );
 use constant $CONSTANTS;
 use constant basetype => "GV";
@@ -666,7 +682,7 @@ sub _more_saved
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 2 );
 use constant $CONSTANTS;
 use constant basetype => "SV";
@@ -828,7 +844,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 3 );
 use constant $CONSTANTS;
 use constant basetype => "SV";
@@ -920,7 +936,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 4 );
 use constant $CONSTANTS;
 use constant basetype => "AV";
@@ -1078,7 +1094,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant type => "PADLIST";
 use constant $CONSTANTS;
 
@@ -1127,7 +1143,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant type => "PADNAMES";
 use constant $CONSTANTS;
 
@@ -1211,7 +1227,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant type => "PAD";
 use constant $CONSTANTS;
 
@@ -1321,7 +1337,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 5 );
 use constant $CONSTANTS;
 use constant basetype => "HV";
@@ -1503,7 +1519,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 6 );
 use constant $CONSTANTS;
 
@@ -1643,7 +1659,7 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 7 );
 use constant $CONSTANTS;
 use constant basetype => "CV";
@@ -2183,7 +2199,7 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 8 );
 use constant $CONSTANTS;
 use constant basetype => "IO";
@@ -2258,7 +2274,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 9 );
 use constant $CONSTANTS;
 use constant basetype => "LV";
@@ -2300,7 +2316,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant basetype => "REGEXP";
 __PACKAGE__->register_type( 10 );
 
@@ -2312,7 +2328,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant basetype => "PVFM";
 __PACKAGE__->register_type( 11 );
 
@@ -2324,7 +2340,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 use constant basetype => "INVLIST";
 __PACKAGE__->register_type( 12 );
 
@@ -2337,7 +2353,7 @@ sub _outrefs { () }
 # A hack to compress files
 package Devel::MAT::SV::_UNDEFSV;
 use base qw( Devel::MAT::SV::SCALAR );
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 __PACKAGE__->register_type( 13 );
 
 sub load
